#-----------------------------------------------------------------------
# File    : bcview.mak
# Contents: build learning vector quantization visualization program
# Author  : Christian Borgelt
# History : 2003.01.28 file created
#           2003.04.13 clustering result visualization added
#           2003.08.11 adapted to new module attmap
#           2003.08.12 adapted to new module nstats
#           2003.08.15 adapted to new module radfn
#           2006.07.20 adapted to Visual Studio 8
#           2016.04.20 creation of dependency files added
#-----------------------------------------------------------------------
THISDIR  = ..\..\bcview\src
UTILDIR  = ..\..\util\src
MATHDIR  = ..\..\math\src
TABLEDIR = ..\..\table\src
MATDIR   = ..\..\matrix\src
BCDIR    = ..\..\bayes\src
CLSDIR   = ..\..\cluster\src
LVQDIR   = ..\..\lvq\src
RBFDIR   = ..\..\rbf\src
DRAWDIR  = ..\..\draw\src

CC       = cl.exe
DEFS     = /D WIN32 /D NDEBUG /D _WINDOWS /D _CRT_SECURE_NO_WARNINGS
CFLAGS   = /nologo /W3 /O2 /GS- $(DEFS) /c
INCS     = /I $(UTILDIR) /I $(MATHDIR) /I $(TABLEDIR) /I $(MATDIR) \
           /I $(BCDIR) /I $(LVQDIR) /I $(CLSDIR) /I $(RBFDIR) \
           /I $(DRAWDIR)

RSC      = rc.exe
RFLAGS   = /l 0x407 /d NDEBUG

LD       = link.exe
LDFLAGS  = /nologo /subsystem:windows /incremental:no
LIBS     = user32.lib comdlg32.lib gdi32.lib

HDRS     = $(UTILDIR)\fntypes.h    $(UTILDIR)\nstats.h     \
           $(UTILDIR)\tabread.h    $(UTILDIR)\tabwrite.h   \
           $(UTILDIR)\scanner.h    $(UTILDIR)\random.h     \
           $(MATHDIR)\radfn.h      $(TABLEDIR)\attset.h    \
           $(TABLEDIR)\attmap.h    $(TABLEDIR)\table.h     \
           $(MATDIR)\matrix.h      $(BCDIR)\nbayes.h       \
           $(BCDIR)\fbayes.h       $(BCDIR)\mvnorm.h       \
           $(LVQDIR)\lvq.h         $(CLSDIR)\cluster.h     \
           $(RBFDIR)\rbf.h         $(DRAWDIR)\wshades.h    \
           bcload.h bvnorm.h wbcview.rh
OBJS     = $(UTILDIR)\arrays.obj   $(UTILDIR)\nst_pars.obj \
           $(UTILDIR)\escape.obj   $(UTILDIR)\tabread.obj  \
           $(UTILDIR)\scanner.obj  $(UTILDIR)\random.obj   \
           $(MATHDIR)\gamma.obj    $(MATHDIR)\radfn.obj    \
           $(TABLEDIR)\attset1.obj $(TABLEDIR)\attset2.obj \
           $(TABLEDIR)\attset3.obj $(TABLEDIR)\attmap.obj  \
           $(TABLEDIR)\table1.obj  $(TABLEDIR)\tab2ro.obj  \
           $(MATDIR)\matrix1.obj   $(MATDIR)\matrix2.obj   \
           $(MATDIR)\matrix3.obj   $(BCDIR)\nbc_exec.obj   \
           $(BCDIR)\fbc_exec.obj   $(BCDIR)\mvn_pars.obj   \
           $(LVQDIR)\lvq.obj       $(CLSDIR)\cluster1.obj  \
           $(CLSDIR)\cluster2.obj  $(RBFDIR)\rbf.obj       \
           $(DRAWDIR)\wshades.obj  \
           bcload.obj bvnorm.obj wbcview.obj wbcview.res
PRGS     = wbcview.exe

#-----------------------------------------------------------------------
# Build Program
#-----------------------------------------------------------------------
all:          $(PRGS)

wbcview.exe:  $(OBJS) bcview.mak
	$(LD) $(LDFLAGS) $(OBJS) $(LIBS) /out:$@

#-----------------------------------------------------------------------
# Main Program
#-----------------------------------------------------------------------
wbcview.obj:  $(HDRS) bcview.mak
	$(CC) $(CFLAGS) $(INCS) wbcview.c /Fo$@

#-----------------------------------------------------------------------
# Resources
#-----------------------------------------------------------------------
wbcview.res:  wbcview.rh wbcview.rc bcview.mak
	$(RSC) $(RFLAGS) /fo$@ wbcview.rc

#-----------------------------------------------------------------------
# Bayes Classifier Loading Routines
#-----------------------------------------------------------------------
bcload.obj:   $(HDRS)
bcload.obj:   bcload.h bcload.c bcview.mak
	$(CC) $(CFLAGS) $(INCS) bcload.c /Fo$@

#-----------------------------------------------------------------------
# Bivariate Normal Distribution Management
#-----------------------------------------------------------------------
bvnorm.obj:   bvnorm.h bvnorm.c bcview.mak
	$(CC) $(CFLAGS) bvnorm.c /Fo$@

#-----------------------------------------------------------------------
# External Modules
#-----------------------------------------------------------------------
$(MATHDIR)\gamma.obj:
	cd $(MATHDIR)
	$(MAKE) /f math.mak gamma.obj
	cd $(THISDIR)
$(MATHDIR)\radfn.obj:
	cd $(MATHDIR)
	$(MAKE) /f math.mak radfn.obj
	cd $(THISDIR)
$(UTILDIR)\arrays.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak arrays.obj
	cd $(THISDIR)
$(UTILDIR)\nst_pars.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak nst_pars.obj
	cd $(THISDIR)
$(UTILDIR)\escape.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak escape.obj
	cd $(THISDIR)
$(UTILDIR)\tabread.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak tabread.obj
	cd $(THISDIR)
$(UTILDIR)\random.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak random.obj
	cd $(THISDIR)
$(UTILDIR)\scanner.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak scanner.obj
	cd $(THISDIR)
$(TABLEDIR)\attset1.obj:
	cd $(TABLEDIR)
	$(MAKE) /f table.mak attset1.obj
	cd $(THISDIR)
$(TABLEDIR)\attset2.obj:
	cd $(TABLEDIR)
	$(MAKE) /f table.mak attset2.obj
	cd $(THISDIR)
$(TABLEDIR)\attset3.obj:
	cd $(TABLEDIR)
	$(MAKE) /f table.mak attset3.obj
	cd $(THISDIR)
$(TABLEDIR)\attmap.obj:
	cd $(TABLEDIR)
	$(MAKE) /f table.mak attmap.obj
	cd $(THISDIR)
$(TABLEDIR)\table1.obj:
	cd $(TABLEDIR)
	$(MAKE) /f table.mak table1.obj
	cd $(THISDIR)
$(TABLEDIR)\tab2ro.obj:
	cd $(TABLEDIR)
	$(MAKE) /f table.mak tab2ro.obj
	cd $(THISDIR)
$(MATDIR)\matrix1.obj:
	cd $(MATDIR)
	$(MAKE) /f matrix.mak matrix1.obj
	cd $(THISDIR)
$(MATDIR)\matrix2.obj:
	cd $(MATDIR)
	$(MAKE) /f matrix.mak matrix2.obj
	cd $(THISDIR)
$(MATDIR)\matrix3.obj:
	cd $(MATDIR)
	$(MAKE) /f matrix.mak matrix3.obj
	cd $(THISDIR)
$(BCDIR)\nbc_exec.obj:
	cd $(BCDIR)
	$(MAKE) /f bayes.mak nbc_exec.obj
	cd $(THISDIR)
$(BCDIR)\fbc_exec.obj:
	cd $(BCDIR)
	$(MAKE) /f bayes.mak fbc_exec.obj
	cd $(THISDIR)
$(BCDIR)\mvn_pars.obj:
	cd $(BCDIR)
	$(MAKE) /f bayes.mak mvn_pars.obj
	cd $(THISDIR)
$(LVQDIR)\lvq.obj:
	cd $(LVQDIR)
	$(MAKE) /f lvq.mak lvq.obj
	cd $(THISDIR)
$(CLSDIR)\cluster1.obj:
	cd $(CLSDIR)
	$(MAKE) /f cluster.mak cluster1.obj
	cd $(THISDIR)
$(CLSDIR)\cluster2.obj:
	cd $(CLSDIR)
	$(MAKE) /f cluster.mak cluster2.obj
	cd $(THISDIR)
$(RBFDIR)\rbf.obj:
	cd $(RBFDIR)
	$(MAKE) /f rbf.mak rbf.obj
	cd $(THISDIR)
$(DRAWDIR)\wshades.obj:
	cd $(DRAWDIR)
	$(MAKE) /f draw.mak wshades.obj
	cd $(THISDIR)

#-----------------------------------------------------------------------
# Install
#-----------------------------------------------------------------------
install:
	-@copy $(PRGS) ..\..\..\bin

#-----------------------------------------------------------------------
# Clean up
#-----------------------------------------------------------------------
clean:
	$(MAKE) /f bcview.mak localclean
	cd $(UTILDIR)
	$(MAKE) /f util.mak clean
	cd $(MATHDIR)
	$(MAKE) /f math.mak clean
	cd $(TABLEDIR)
	$(MAKE) /f table.mak localclean
	cd $(MATDIR)
	$(MAKE) /f matrix.mak localclean
	cd $(BCDIR)
	$(MAKE) /f bayes.mak localclean
	cd $(CLSDIR)
	$(MAKE) /f cluster.mak localclean
	cd $(RBFDIR)
	$(MAKE) /f rbf.mak localclean
	cd $(DRAWDIR)
	$(MAKE) /f draw.mak clean
	cd $(THISDIR)

localclean:
	-@erase /Q *~ *.obj *.idb *.pch *.res $(PRGS)
